@@ -1,13 +1,15 @@
-#ifndef PLAYLIST_H
+﻿#ifndef PLAYLIST_H
 #define PLAYLIST_H
 
 #include <QObject>
 #include <QVariant>
+#include <QQmlParserStatus>
 
 class TracksModel;
 class Player;
-class Playlist : public QObject
+class Playlist : public QObject, public QQmlParserStatus
 {
+    Q_INTERFACES(QQmlParserStatus)
     Q_OBJECT
 
     Q_PROPERTY(TracksModel *model WRITE setModel READ model NOTIFY modelChanged)
@@ -18,6 +20,8 @@ class Playlist : public QObject
 
     Q_PROPERTY(RepeatMode repeatMode READ repeatMode WRITE setRepeatMode NOTIFY repeatModeChanged)
 
+    Q_PROPERTY(bool autoResume READ autoResume WRITE setAutoResume NOTIFY autoResumeChanged)
+
 public:
     enum PlayMode : uint_fast8_t
     {
@@ -44,17 +48,20 @@ public:
 
     RepeatMode repeatMode() const;
 
+    bool autoResume() const;
+
 private:
     TracksModel *m_model = nullptr;
     Player *m_player = nullptr;
     QVariantMap m_currentTrack;
     int m_currentIndex = -1;
-    int m_previousIndex = -1;
 
     PlayMode m_playMode = PlayMode::Normal;
     RepeatMode m_repeatMode = RepeatMode::NoRepeat;
     uint m_repeatFlag = 0;
 
+    bool m_autoResume;
+
 public slots:
     bool canGoNext() const;
     bool canGoPrevious() const;
@@ -62,7 +69,6 @@ public slots:
 
     void next();
     void previous();
-    void nextShuffle();
     void play(int index);
     void clear();
 
@@ -78,11 +84,15 @@ public slots:
 
     void setPlayMode(Playlist::PlayMode playMode);
 
+    void shuffleRange(int start, int stop);
+
     void move(int from, int to);
     void remove(int index);
 
     void setRepeatMode(RepeatMode repeatMode);
 
+    void setAutoResume(bool autoResume);
+
 signals:
     void canPlayChanged();
     void modelChanged(TracksModel *model);
@@ -91,6 +101,13 @@ signals:
     void missingFile(QVariantMap track);
     void playModeChanged(Playlist::PlayMode playMode);
     void repeatModeChanged(RepeatMode repeatMode);
+    void autoResumeChanged(bool autoResume);
+
+    // QQmlParserStatus interface
+public:
+    void classBegin() override final;
+    void componentComplete() override final;
 };
 
+
 #endif // PLAYLIST_H
